==> downloads.html?file=gigkalender_v1.2.66_014_update-72_002.zip: gigkalender/calendar/backend_selectGig.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Gig_Selection.'</p>';
  if ( !loggedIn() ) { echo $L_003; }
  else
  {
    // Inhalt hier einfügen  
      if ( AnzahlGigsMitGleichemDatum($timestamp)=='0' )
      {
        echo $L_156.'<br /><br />';
      }
      else
      { 
        // Publish or Not
          if (isset($_POST['GigPublish_x'])) { changeGigPublishing ($_POST['GigID']); }
        // IsPrivate or Not
          if (isset($_POST['GigIsPrivate_x'])) { changeGigIsPrivate ($_POST['GigID']); }
        // Seiten-Navigation definieren
        // Session-Variable 'Zeitraum' definieren
          if ( isset($_POST['Zeitraum']) ) { $_SESSION["Zeitraum"] = $_POST['Zeitraum']; }
          if ( !isset($_SESSION["Zeitraum"]) ) { $_SESSION["Zeitraum"] = "future"; }
          $Zeitraum = $_SESSION["Zeitraum"];
        // Sessioin-Variable 'Anzahl' definieren
          if ( isset($_POST['Anzahl']) ) { $_SESSION["Anzahl"] = $_POST['Anzahl']; }
          if ( !isset($_SESSION["Anzahl"]) ) { $_SESSION["Anzahl"] = "10"; }
          $EintraegeProSeite = $_SESSION["Anzahl"];
        // Sessioin-Variable 'GigStatus' definieren
          if ( isset($_POST['AuswahlGigStatus']) ) { $_SESSION["AuswahlGigStatus"] = $_POST['AuswahlGigStatus']; }
          if ( !isset($_SESSION["AuswahlGigStatus"]) ) { $_SESSION["AuswahlGigStatus"] = "all"; }
          $AuswahlGigStatus = $_SESSION["AuswahlGigStatus"];
        // Parameter für Navigation definieren
          $AnzahlGigsImZeitraum = AnzahlGigsImZeitraum($Zeitraum, $AuswahlGigStatus);
          if ( $EintraegeProSeite!='all' ) { $AnzahlSeiten = ceil($AnzahlGigsImZeitraum/$EintraegeProSeite); }
          else { $AnzahlSeiten = '0'; }
          if (isset($_REQUEST['page'])) { $aktuelleSeite = $_REQUEST['page']; } else { $aktuelleSeite = ""; }
          if ($aktuelleSeite == "") { $aktuelleSeite="1"; }      
          $obersterGig  = $EintraegeProSeite*($aktuelleSeite-1);
      // Datensatz-Ausgabe festlegen
        $TimestampVonHeute = TimestampAusDatum(date("d"), date("m"), date("y")); 
        
        $sql = "SELECT * FROM ".$prefix."gigs WHERE GigDate=".$timestamp;
        $resultat = mysqli_query($db, $sql);

      // Ausgabe der Gig-Übersicht
        if ( $AnzahlGigsImZeitraum!=0 ) // Einträge vorhanden
        {   
          // Spalten definieren
            $UserBackendCalenderListCols = getCurrentUserVar ('UserBackendCalenderListCols');
            if ( $UserBackendCalenderListCols!="" ) $Attribute = explode (', ',$UserBackendCalenderListCols);
            else $Attribute = array();
            
          echo '<table id="WideTable" summary="Tabelle_Zeige-Gigs">';
          echo '<colgroup>';
          if ( IsUserAdmin() ) { echo '<col class="SpalteIcon" />'; }
          echo '<col class="SpalteIcon" />';
          echo '<col class="GigStatus" />';
          for ($i=0; $i<(count($Attribute)); $i++)
          {
            echo '<col id="'.$Attribute[$i].'" />';
          }
          echo '</colgroup>';
          echo '<tr>';
          if ( IsUserAdmin() ) { echo'<th>&nbsp;</th>'; }
          echo '<th>&nbsp;</th>
                <th>'.$L_GigDate.'</th>';
          // ColGigStatusPrint
          echo '<th class="GigPrint">'.$L_GigStatus.'</th>';
          // Definierte Spalten
            for ( $x = 0; $x < count ( $Attribute ); $x++ )
              {
                if ( $x!=count($Attribute)-1 ) echo '<th>';
                else echo '<th class="TabellenSpalte_Rechts">';

                switch ( $Attribute[$x] )
                {
                  case "GigIsPrivate": echo '<img src="images/private.gif" alt="'.$L_Private.'" title="'.$L_Private.'" />'; break;
                  case "GigPublish": echo '<img src="images/frontend.gif" alt="'.$L_Publish.'" title="'.$L_Publish.'" />'; break;
                  case "GigBeginning": echo '<img src="images/time.gif" alt="" title="" />'; break;
                  default: echo ''.${'L_'.$Attribute[$x]}; break;
                }
                echo '</th>';
              }
          //
          echo '</tr>';
          while ($row = mysqli_fetch_array($resultat))
          {
            extract($row);
            echo '<tr>';
            if ( IsUserAdmin() )
            {
              echo '<td class="'.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;inhalt=backend_delGig&amp;id='.$GigID.'">
                        <img src="images/delete.gif" alt="'.$L_009.'" title="'.$L_009.'" /></a>
                    </td>
                    <td class="'.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;inhalt=backend_addGig&amp;job=edit&amp;id='.$GigID.'">
                        <img src="images/edit.gif" alt="'.$L_010.'" title="'.$L_010.'" /></a>
                    </td>';
            }
            else
            {
              echo '<td class="'.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;inhalt=backend_showGig&amp;id='.$GigID.'">
                        <img src="images/show.png" alt="'.$L_153.'" title="'.$L_153.'" /></a>
                    </td>';
            }
            // GigDate
            echo '<td class="'.$GigStatus.'">'.date($SetupBackendDateFormat, $GigDate).'</td>';
            // ColGigStatusPrint
            echo '<td class="GigPrint">'.$GigStatus.'</td>';
            // Definierte Spalten
            for ( $x = 0; $x < count ( $Attribute ); $x++ )
            {
              echo '<td class="'.$GigStatus.'" style="white-space: nowrap;">';
              include ('calendar/includes/showAllGigs/'.$Attribute[$x].'.php');
              echo '</td>';
            }
            //
            echo '</tr>';
            //$Location = '';
          }
          echo '</table>';
          include("calendar/backend_legende.php");
        }
        else { echo $L_154."<br />";}
      }
    // Inhalt zuende
  }
?>

==> downloads.html?file=gigkalender_v1.2.75_017_update-80_040.zip: gigkalender/calendar/backend_selectGig.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Gig_Selection.'</p>';
  if ( !loggedIn() ) { echo $L_003; }
  else
  {
    // Inhalt hier einfügen  
      if ( AnzahlGigsMitGleichemDatum($timestamp)=='0' )
      {
        echo $L_156.'<br /><br />';
      }
      else
      { 
        // Publish or Not
          if (isset($_POST['GigPublish_x'])) { changeGigPublishing ($_POST['GigID']); }
        // IsPrivate or Not
          if (isset($_POST['GigIsPrivate_x'])) { changeGigIsPrivate ($_POST['GigID']); }
        // Seiten-Navigation definieren
        // Session-Variable 'Zeitraum' definieren
          if ( isset($_POST['Zeitraum']) ) { $_SESSION["Zeitraum"] = $_POST['Zeitraum']; }
          if ( !isset($_SESSION["Zeitraum"]) ) { $_SESSION["Zeitraum"] = "future"; }
          $Zeitraum = $_SESSION["Zeitraum"];
        // Session-Variable 'Anzahl' definieren
          if ( isset($_POST['Anzahl']) ) { $_SESSION["Anzahl"] = $_POST['Anzahl']; }
          if ( !isset($_SESSION["Anzahl"]) ) { $_SESSION["Anzahl"] = "10"; }
          $EintraegeProSeite = $_SESSION["Anzahl"];
        // Session-Variable 'GigStatus' definieren
          if ( isset($_POST['AuswahlGigStatus']) ) { $_SESSION["AuswahlGigStatus"] = $_POST['AuswahlGigStatus']; }
          if ( !isset($_SESSION["AuswahlGigStatus"]) ) { $_SESSION["AuswahlGigStatus"] = "all"; }
          $AuswahlGigStatus = $_SESSION["AuswahlGigStatus"];
        // Parameter für Navigation definieren
          $AnzahlGigsImZeitraum = AnzahlGigsImZeitraum($Zeitraum, $AuswahlGigStatus);
          if ( $EintraegeProSeite!='all' ) { $AnzahlSeiten = ceil($AnzahlGigsImZeitraum/$EintraegeProSeite); }
          else { $AnzahlSeiten = '0'; }
          if (isset($_REQUEST['page'])) { $aktuelleSeite = $_REQUEST['page']; } else { $aktuelleSeite = ""; }
          if ($aktuelleSeite == "") { $aktuelleSeite="1"; }      
          $obersterGig  = $EintraegeProSeite*($aktuelleSeite-1);
      // Datensatz-Ausgabe festlegen
        $TimestampVonHeute = TimestampAusDatum(date("d"), date("m"), date("y")); 
        
        $sql = "SELECT * FROM ".$prefix."gigs WHERE GigDate=".$timestamp;
        $resultat = mysqli_query($db, $sql);

      // Ausgabe der Gig-Übersicht
        if ( $AnzahlGigsImZeitraum!=0 ) // Einträge vorhanden
        {   
          // Spalten definieren
            $UserBackendCalenderListCols = getCurrentUserVar ('UserBackendCalenderListCols');
            if ( $UserBackendCalenderListCols!="" ) $Attribute = explode (', ',$UserBackendCalenderListCols);
            else $Attribute = array();
            
          echo '<table id="WideTable" summary="Tabelle_Zeige-Gigs">';
          echo '<colgroup>';
          if ( IsUserAdmin() ) { echo '<col class="SpalteIcon" />'; }
          echo '<col class="SpalteIcon" />';
          echo '<col class="GigStatus" />';
          for ($i=0; $i<(count($Attribute)); $i++)
          {
            echo '<col id="'.$Attribute[$i].'" />';
          }
          echo '</colgroup>';
          echo '<tr>';
          if ( IsUserAdmin() ) { echo'<th>&nbsp;</th>'; }
          echo '<th>&nbsp;</th>
                <th>'.$L_GigDate.'</th>';
          // ColGigStatusPrint
          echo '<th class="GigPrint">'.$L_GigStatus.'</th>';
          // Definierte Spalten
            for ( $x = 0; $x < count ( $Attribute ); $x++ )
              {
                if ( $x!=count($Attribute)-1 ) echo '<th>';
                else echo '<th class="TabellenSpalte_Rechts">';

                switch ( $Attribute[$x] )
                {
                  case "GigIsPrivate": echo '<img src="images/private.gif" alt="'.$L_Private.'" title="'.$L_Private.'" />'; break;
                  case "GigPublish": echo '<img src="images/frontend.gif" alt="'.$L_Publish.'" title="'.$L_Publish.'" />'; break;
                  case "GigBeginning": echo '<img src="images/time.gif" alt="" title="" />'; break;
                  default: echo ''.${'L_'.$Attribute[$x]}; break;
                }
                echo '</th>';
              }
          //
          echo '</tr>';
          while ($row = mysqli_fetch_array($resultat))
          {
            extract($row);
            echo '<tr>';
            if ( IsUserAdmin() )
            {
              echo '<td class="'.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;content=backend_delGig&amp;id='.$GigID.'">
                        <img src="images/delete.gif" alt="'.$L_009.'" title="'.$L_009.'" /></a>
                    </td>
                    <td class="'.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;content=backend_addGig&amp;job=edit&amp;id='.$GigID.'">
                        <img src="images/edit.gif" alt="'.$L_010.'" title="'.$L_010.'" /></a>
                    </td>';
            }
            else
            {
              echo '<td class="'.$GigStatus.'">
                      <a href="index.php?submenue=calendar&amp;content=backend_showGig&amp;id='.$GigID.'">
                        <img src="images/show.png" alt="'.$L_153.'" title="'.$L_153.'" /></a>
                    </td>';
            }
            // GigDate
            echo '<td class="'.$GigStatus.'">'.date($SetupBackendDateFormat, $GigDate).'</td>';
            // ColGigStatusPrint
            echo '<td class="GigPrint">'.$GigStatus.'</td>';
            // Definierte Spalten
            for ( $x = 0; $x < count ( $Attribute ); $x++ )
            {
              echo '<td class="'.$GigStatus.'" style="white-space: nowrap;">';
              include ('calendar/includes/showAllGigs/'.$Attribute[$x].'.php');
              echo '</td>';
            }
            //
            echo '</tr>';
            //$Location = '';
          }
          echo '</table>';
          include("calendar/backend_legende.php");
        }
        else { echo $L_154."<br />";}
      }
    // Inhalt zuende
  }
?>
